<?php

namespace Pinpoint\CarouselManager\Model\Resolver\DataProvider;

use Magento\Framework\Api\SearchCriteriaBuilder;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\GraphQl\Exception\GraphQlNoSuchEntityException;
use Pinpoint\CarouselManager\Model\CarouselRepository;
use Pinpoint\CarouselManager\Model\SlideRepository;

/**
 * Carousel Data Provider.
 */
class Carousel
{
    /**
     * @var SearchCriteriaBuilder
     */
    protected $searchCriteriaBuilder;

    /**
     * @var CarouselRepository
     */
    protected $carouselRepository;

    /**
     * @var SlideRepository
     */
    protected $slideRepository;

    /**
     * @param SearchCriteriaBuilder $searchCriteriaBuilder
     * @param CarouselRepository $carouselRepository
     */
    public function __construct(
        SearchCriteriaBuilder $searchCriteriaBuilder,
        CarouselRepository $carouselRepository,
        SlideRepository $slideRepository
    ) {
        $this->searchCriteriaBuilder = $searchCriteriaBuilder;
        $this->carouselRepository = $carouselRepository;
        $this->slideRepository = $slideRepository;
    }

    /**
     * @param int $carouselId
     * @return mixed
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getCarousel(int $carouselId)
    {
        return $this->carouselRepository->getById($carouselId);
    }

    /**
     * @return array
     * @throws GraphQlNoSuchEntityException
     */
    public function getSlides(int $carouselId)
    {
        $slides = [];
        try {
            $this->searchCriteriaBuilder->addFilter('carousel_id', ['eq' => $carouselId]);
            $data = $this->slideRepository->getList($this->searchCriteriaBuilder->create());
            foreach ($data->getItems() as $item) {
                $slides[] = [
                    'title' => $item['title'],
                    'description' => $item['description'],
                    'eventCategory' => $item['event_category'],
                    'eventAction' => $item['event_action'],
                    'cta' => $item['cta'],
                    'ctaBackgroundColour' => $item['cta_background_color'],
                    'ctaTextColour' => $item['cta_text_color'],
                    'ctaPosition' => $item['cta_text_position'],
                    'slideLink' => $item['link'],
                    'slideVideo' => $item['video'],
                    'slideMobileVideo' => $item['mobile_video'],
                    'slideImage' => $item['image'],
                    'slideMobileImage' => $item['mobile_image'],
                    'slideSortOrder' => $item['sort'],
                ];
            }
        } catch (NoSuchEntityException $e) {
            throw new GraphQlNoSuchEntityException(__($e->getMessage()), $e);
        }
        return $slides;
    }
}
